@@ -8,7 +8,7 @@
 
     This file is part of fs_filepicker.
 
-    :copyright: Copyright 2017 Reimar Bauer
+    :copyright: Copyright 2017-2018 Reimar Bauer
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -23,7 +23,8 @@
     See the License for the specific language governing permissions and
     limitations under the License.
 """
-from conftest import ROOT_FS, TESTDATA_DIR
+import fs.path
+from conftest import ROOT_DIR, TESTDATA_DIR
 from datetime import datetime
 from fslib.utils import match_extension, get_extension_from_string, human_readable_info, fs_url_exists, fs_file_exists
 
@@ -58,4 +59,4 @@ def test_fs_url_exists():
 
 
 def test_fs_file_exists():
-    assert fs_file_exists(ROOT_FS, TESTDATA_DIR)
+    assert fs_file_exists(fs.path.join(ROOT_DIR, TESTDATA_DIR), u'example.csv')
