@@ -588,15 +588,21 @@ def fs_filepicker(parent=None, fs_url=u'~/', file_pattern=u'All Files (*)', titl
         if parseresult is not None:
             active_url = u"{}://{}{}".format(parseresult.protocol, fp.authentification, parseresult.resource)
     filename = None
+    selected_file_pattern = None
     if fp.filename is not None:
         dirname = u'.{}'.format(u"/")
         if fp.wparm is not None:
             dirname = fp.selected_dir
         if dirname.startswith(fp.active_url):
-            filename = u"{}{}".format(active_url, fp.filename)
+            filename = u"{}{}".format(fs.path.forcedir(active_url), fp.filename)
         else:
-            filename = fs.path.abspath(fs.path.join(u"{}{}".format(active_url, dirname), fp.filename))
-    return filename, fp.selected_file_pattern[0]
+            # We can't use fs.path.join and also not fs.path.abspath because of protocol url
+            filename = u"{}{}{}".format(fs.path.forcedir(active_url), fs.path.forcedir(dirname), fp.filename)
+        try:
+            selected_file_pattern = fp.selected_file_pattern[0]
+        except TypeError:
+            selected_file_pattern = file_pattern
+    return filename, selected_file_pattern
 
 
 def getOpenFileName(parent=None, fs_url=u'~/', file_pattern=u'All Files (*)', title=u'FS File Picker', **options):
