@@ -8,7 +8,7 @@
 
     This file is part of fs_filepicker.
 
-    :copyright: Copyright 2017 Reimar Bauer
+    :copyright: Copyright 2017-2018 Reimar Bauer
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -118,8 +118,11 @@ def fs_file_exists(fs_url, filename):
         _fs = fs.open_fs(fs_url)
     except fs.errors.CreateFailed:
         return False
-    # ToDo needs speedup
-    return filename in _fs.listdir(u'.')
+    try:
+        _fs.exists(filename)
+        return True
+    except fs.errors.ResourceNotFound:
+        return False
 
 
 class WidgetImage(QWidget):
